Uses the param_model (which maps covariate inputs to theta_s) to
extract the modelled saturated water content for each row of newdata.
Uses the param_model (which maps covariate inputs to theta_s) to
extract the modelled saturated water content for each row of newdata.