Returns R², RMSE, and MAE between observed and predicted volumetric water content (or any continuous response).
Value
A tibble::tibble() with one row and columns R2, RMSE,
MAE, n (number of non-missing pairs).
Returns R², RMSE, and MAE between observed and predicted volumetric water content (or any continuous response).
A tibble::tibble() with one row and columns R2, RMSE,
MAE, n (number of non-missing pairs).