Dispatches to predict_swrc().
Usage
# S3 method for class 'swrc_fit'
predict(object, newdata, pf = NULL, heads = NULL, ...)Arguments
- object
A
swrc_fitobject returned byfit_swrc().- newdata
A data frame with the same covariate columns used during training (i.e.
object$x_inputs). Must have amatric_headcolumn or supplypfdirectly.- pf
Optional numeric vector of pF values (overrides
matric_headinnewdata).- heads
Optional numeric vector of matric heads in cm (overrides
matric_headinnewdata).- ...
Ignored.