soilFlux: Physics-Informed Neural Networks for Soil Water Retention Curves
Source:R/zzz.R
soilFlux-package.RdThe soilFlux package implements a physics-informed 1-D convolutional
neural network (CNN1D-PINN) for estimating the complete soil water
retention curve (SWRC) as a continuous function of matric potential,
from soil texture, organic carbon, bulk density, and depth.
Details
Main functions
| Function | Purpose |
prepare_swrc_data() | Standardise raw soil data |
fit_swrc() | Train the CNN1D-PINN model |
predict_swrc() | Predict theta at given pF values |
predict_swrc_dense() | Predict full SWRC curves |
swrc_metrics() | Evaluate model performance |
plot_swrc() | Plot retention curves |
plot_pred_obs() | Predicted vs. observed plot |
save_swrc_model() / load_swrc_model() | Persist the model |
classify_texture() | USDA texture classification |
References
Norouzi, A. M., et al. (2025). "Physics-Informed Neural Networks for Estimating a Continuous Form of the Soil Water Retention Curve." Water Resources Research. doi:10.1029/2024WR038149
Author
Maintainer: Hugo Rodrigues rodrigues.machado.hugo@gmail.com (ORCID)